import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {areaRecord} from "@/api/demo/cascader"; // 引入开关组件
type CheckedType = boolean | string | number;

export const columnsTwo: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '类型',
    dataIndex: 'type',
    width: 120,
  },
]
export const columns: BasicColumn[] = [
  {
    title: '文件中文名',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '文件英文全称',
    dataIndex: 'englishName',
    width: 120,
  },
  {
    title: '名词英文简称',
    dataIndex: 'abbreviation',
    width: 120,
  },
  {
    title: '发布状态',
    dataIndex: 'flag',
    width: 120,
  },
  {
    title: '权属工作组',
    dataIndex: 'group',
    width: 120,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名词中文名',
    component: 'Input',
    colProps: { span: 6 },
    componentProps: {
      placeholder: '输入名词中文名',
    },
  },
  {
    field: 'english',
    label: '名词英文名',
    component: 'Input',
    colProps: { span: 6 },
    componentProps: {
      placeholder: '输入名词英文名',
    },
  },
  {
    field: 'abbreviation',
    label: '名词英文简称',
    component: 'Input',
    colProps: { span: 6 },
    componentProps: {
      placeholder: '输入名词英文简称',
    },
  },
];


export const formSchema: FormSchema[] = [

  {
    field: 'path',
    component: 'Cascader',
    label: '路径',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
  {
    field: 'name',
    label: '名词分类名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入名词分类名称',
      },
    ],
  },
  {
    field: 'describe',
    component: 'InputTextArea',
    label: '标准分类描述',
    required: true,
    componentProps: {
      placeholder: '请输入标准分类描述',
      rows: 4,
    },
  },
  {
    field: 'modal',
    component: 'Cascader',
    label: '关联元模型',
    required: true,
    componentProps: {
      // dataField: 'data',
      labelField: 'value',
      valueField: 'label',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
]
export const formSchemaManage: FormSchema[] = [

  {
    field: 'path',
    component: 'Cascader',
    label: '路径',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
  {
    field: 'name',
    label: '名词中文名',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入名词中文名',
      },
    ],
  },
  {
    field: 'type',
    label: '标准类型',
    component: 'Input',
    defaultValue:'命名字典',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'modal',
    label: '目录权属模式',
    component: 'Input',
    defaultValue:'本级定义',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'group',
    label: '权属工作组',
    component: 'Input',
    defaultValue:'-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]

/**详情表单1*/
export const detailSchema1: FormSchema[] = [
  {
    field: 'valueOne',
    label: '所属主题',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'标准文件管理',
    rules: [
      {
        required: true,
        message: '请输入所属主题',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入所属主题',
    },
  },
  {
    field: 'valueTwo',
    label: '标准编号',
    component: 'Input',
    defaultValue: 'REF000023',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'valueThree',
    label: '标准中文名称',
    component: 'Input',
    defaultValue:'标准文件A',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'valueFour',
    label: '来源定义',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue: '-',
    rules: [
      {
        required: true,
        message: '请输入来源定义',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入来源定义',
    },
  },
  {
    field: 'valueFive',
    label: '发文机构',
    component: 'Input',
    defaultValue: '某部队',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入发文机构',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSix',
    label: '发文日期',
    component: 'Input',
    defaultValue: '202304',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入发文日期',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSeven',
    label: '发布文号',
    component: 'Input',
    defaultValue: '2023001',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入发布文号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入发布文号',
    },
  },
  {
    field: 'valueEight',
    label: '重点摘录',
    component: 'Input',
    defaultValue: '-',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入重点摘录',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入重点摘录',
    },
  },
];

export const detailSchema2: FormSchema[] = [
  {
    field: 'valueOne',
    label: '所属主题',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'标准文件管理',
    componentProps: {
      placeholder: '请输入所属主题',
    },
  },
  {
    field: 'valueTwo',
    label: '标准编号',
    component: 'Input',
    defaultValue: 'REF000023',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'valueThree',
    label: '标准中文名称',
    component: 'Input',
    defaultValue:'标准文件A',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'valueFour',
    label: '来源定义',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue: '-',
    componentProps: {
      placeholder: '请输入来源定义',
    },
  },
  {
    field: 'valueFive',
    label: '发文机构',
    component: 'Input',
    defaultValue: '某部队',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSix',
    label: '发文日期',
    component: 'Input',
    defaultValue: '202304',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSeven',
    label: '发布文号',
    component: 'Input',
    defaultValue: '2023001',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入发布文号',
    },
  },
  {
    field: 'valueEight',
    label: '重点摘录',
    component: 'Input',
    defaultValue: '-',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入重点摘录',
    },
  },
];
export const formSchemaImport: any = [
  {
    field: 'path',
    label: '选择文件地址',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'name',
    label: '文件名',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件名',
    },
  },
]
